@@ -1,4 +1,4 @@
-from method import method
+from method.method import Method
 from method.configuration import Configuration
 from method.errors import MethodInternalError
 from method.errors import MethodAuthorizationError
